.. -*- coding: utf-8 -*-

.. _DataModel:

Data model
==========

This chapter describes how you define a schema and how to make it evolves as the time goes.

.. toctree::
   :maxdepth: 1

   definition
   metadata
   baseschema
   define-workflows
